How to use the :mod:`zhinst-toolkit`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^


.. toctree::
   :maxdepth: 2

   notebooks/example1_getting_started
   tour
   awgCore
   notebooks/example4_DAQModule
   notebooks/example5_SweeperModule
